@@ -354,6 +354,7 @@ class access(object):
 
 		if ca_certfile:
 			self.lo.set_option(ldap.OPT_X_TLS_CACERTFILE, ca_certfile)
+			self.lo.set_option(ldap.OPT_X_TLS_NEWCTX, 0)
 
 		if self.protocol.lower() != 'ldaps':
 			if self.start_tls == 1:
@@ -425,7 +426,7 @@ class access(object):
 
 	@_fix_reconnect_handling
 	def get(self, dn, attr=[], required=False):
-		# type: (str, List[str], bool) -> Dict[str, List[str]]
+		# type: (str, List[str], bool) -> Dict[str, List[bytes]]
 		"""
 		Return multiple attributes of a single LDAP object.
 
@@ -434,7 +435,7 @@ class access(object):
 		:type attr: list[str]
 		:param bool required: Raise an exception instead of returning an empty dictionary.
 		:returns: A dictionary mapping the requested attributes to a list of their values.
-		:rtype: dict[str, list[str]]
+		:rtype: dict[str, list[bytes]]
 		:raises ldap.NO_SUCH_OBJECT: If the LDAP object is not accessible.
 		"""
 		if dn:
@@ -449,7 +450,7 @@ class access(object):
 
 	@_fix_reconnect_handling
 	def getAttr(self, dn, attr, required=False):
-		# type: (str, str, bool) -> List[str]
+		# type: (str, str, bool) -> List[bytes]
 		"""
 		Return a single attribute of a single LDAP object.
 
@@ -457,7 +458,7 @@ class access(object):
 		:param str attr: The attribute to fetch.
 		:param bool required: Raise an exception instead of returning an empty dictionary.
 		:returns: A list of values.
-		:rtype: list[str]
+		:rtype: list[bytes]
 		:raises ldap.NO_SUCH_OBJECT: If the LDAP object is not accessible.
 
 		.. warning:: the attribute name is currently case sensitive and must be given as in the LDAP schema
@@ -476,7 +477,7 @@ class access(object):
 
 	@_fix_reconnect_handling
 	def search(self, filter='(objectClass=*)', base='', scope='sub', attr=[], unique=False, required=False, timeout=-1, sizelimit=0, serverctrls=None, response=None):
-		# type: (str, str, str, List[str], bool, bool, int, int, Optional[List[ldap.controls.LDAPControl]], Optional[Dict[str, ldap.controls.LDAPControl]]) -> List[Tuple[str, Dict[str, List[str]]]]
+		# type: (str, str, str, List[str], bool, bool, int, int, Optional[List[ldap.controls.LDAPControl]], Optional[Dict[str, ldap.controls.LDAPControl]]) -> List[Tuple[str, Dict[str, List[bytes]]]]
 		"""
 		Perform LDAP search and return values.
 
@@ -493,7 +494,7 @@ class access(object):
 		:type serverctrls: list[ldap.controls.LDAPControl]
 		:param dict response: An optional dictionary to receive the server controls of the result.
 		:returns: A list of 2-tuples (dn, values) for each LDAP object, where values is a dictionary mapping attribute names to a list of values.
-		:rtype: list[tuple[str, dict[str, list[str]]]]
+		:rtype: list[tuple[str, dict[str, list[bytes]]]]
 		:raises ldap.NO_SUCH_OBJECT: Indicates the target object cannot be found.
 		:raises ldap.INAPPROPRIATE_MATCHING: Indicates that the matching rule specified in the search filter does not match a rule defined for the attribute's syntax.
 		"""
@@ -984,6 +985,7 @@ class access(object):
 
 			if self.ca_certfile:
 				lo_ref.set_option(ldap.OPT_X_TLS_CACERTFILE, self.ca_certfile)
+				lo_ref.set_option(ldap.OPT_X_TLS_NEWCTX, 0)
 
 			if self.start_tls == 1:
 				try:
